==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/ca.js <==
OC.L10N.register(
    "settings",
    {
    "Enabled" : "Activat",
    "Not enabled" : "Desactivat",
    "Wrong password" : "Contrasenya incorrecta",
    "Saved" : "Desat",
    "No user supplied" : "No heu proporcionat cap usuari",
    "Unable to change password" : "No es pot canviar la contrasenya",
    "Authentication error" : "Error d'autenticació",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Sisplau, proporcioneu una contrasenya de recuperació d'administrador, altrament totes les dades d'usuari es perdran",
    "Wrong admin recovery password. Please check the password and try again." : "La contrasenya de recuperació d'administrador és incorrecta. Comproveu-la i torneu-ho a intentar.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "El backend no admet canvis de contrasenya, però la clau de xifrat de l'usuari ha estat actualitzada satisfactòriament.",
    "Federated Cloud Sharing" : "Compartició federada de núvol",
    "A problem occurred, please check your log files (Error: %s)" : "S'ha produït un problema, si us plau revisi els arxius de registre (Error: %s)",
    "Migration Completed" : "Migració completada",
    "Group already exists." : "El grup ja existeix.",
    "Unable to add group." : "No es pot agregar el grup.",
    "Unable to delete group." : "No es pot esborrar el grup.",
    "test email settings" : "prova l'arranjament del correu",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Hi ha hagut un problema en enviar el correu. Revisi la seva configuració. (Error: %s)",
    "Email sent" : "El correu electrónic s'ha enviat",
    "You need to set your user email before being able to send test emails." : "Heu d'establir un nom d'usuari abans de poder enviar correus de prova.",
    "Invalid request" : "Sol·licitud no vàlida",
    "Invalid mail address" : "Adreça de correu invàlida",
    "A user with that name already exists." : "Ja existeix un usuari amb est nom.",
    "Unable to create user." : "No es pot crear el usuari.",
    "Your %s account was created" : "S'ha creat el seu compte %s",
    "Unable to delete user." : "No es pot eliminar l'usuari",
    "Unable to change full name" : "No s'ha pogut canviar el nom complet",
    "Your full name has been changed." : "El vostre nom complet ha canviat.",
    "Forbidden" : "Prohibit",
    "Invalid user" : "Usuari no vàlid",
    "Unable to change mail address" : "No es pot canviar l'adreça de correu electrònic",
    "Email saved" : "S'ha desat el correu electrònic",
    "Couldn't remove app." : "No s'ha pogut eliminar l'aplicació",
    "Admins can't remove themself from the admin group" : "Els administradors no es poden eliminar del grup admin",
    "Unable to add user to group %s" : "No es pot afegir l'usuari al grup %s",
    "Unable to remove user from group %s" : "No es pot eliminar l'usuari del grup %s",
    "Couldn't update app." : "No s'ha pogut actualitzar l'aplicació.",
    "Add trusted domain" : "Afegir domini de confiança",
    "Migration in progress. Please wait until the migration is finished" : "Migració en progrés. Si us plau, espereu fins que finalitzi la migració",
    "Migration started …" : "Migració iniciada ...",
    "Sending..." : "Enviant...",
    "Official" : "Oficial",
    "All" : "Tots",
    "Update to %s" : "Actualitzar a %s",
    "No apps found for your version" : "No s'han trobat aplicacions per la seva versió",
    "Error while disabling app" : "Error en desactivar l'aplicació",
    "Disable" : "Desactiva",
    "Enable" : "Habilita",
    "Error while enabling app" : "Error en activar l'aplicació",
    "Updating...." : "Actualitzant...",
    "Error while updating app" : "Error en actualitzar l'aplicació",
    "Updated" : "Actualitzada",
    "Uninstalling ...." : "Desintal·lant ...",
    "Error while uninstalling app" : "Error en desinstal·lar l'aplicació",
    "Uninstall" : "Desinstal·la",
    "Approved" : "Aprovat",
    "Experimental" : "Experimental",
    "Valid until {date}" : "Vàlid fins {date}",
    "Delete" : "Esborra",
    "Select a profile picture" : "Seleccioneu una imatge de perfil",
    "Very weak password" : "Contrasenya massa feble",
    "Weak password" : "Contrasenya feble",
    "So-so password" : "Contrasenya passable",
    "Good password" : "Contrasenya bona",
    "Strong password" : "Contrasenya forta",
    "Groups" : "Grups",
    "Unable to delete {objName}" : "No es pot eliminar {objName}",
    "A valid group name must be provided" : "Heu de facilitar un nom de grup vàlid",
    "deleted {groupName}" : "eliminat {groupName}",
    "undo" : "desfés",
    "never" : "mai",
    "deleted {userName}" : "eliminat {userName}",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Canviar la contrasenya provocarà pèrdua de dades, perquè la recuperació de dades no està disponible per a aquest usuari",
    "A valid username must be provided" : "Heu de facilitar un nom d'usuari vàlid",
    "A valid password must be provided" : "Heu de facilitar una contrasenya vàlida",
    "A valid email must be provided" : "S'ha de subministrar una adreça de correu electrònic vàlida",
    "__language_name__" : "Català",
    "Unlimited" : "Il·limitat",
    "Personal info" : "Informació personal",
    "Sync clients" : "Sincronitzar clients",
    "None" : "Cap",
    "Login" : "Inici de sessió",
    "Plain" : "Pla",
    "NT LAN Manager" : "Gestor NT LAN",
    "Email server" : "Servidor de correu electrònic",
    "Open documentation" : "Obre la documentació",
    "This is used for sending out notifications." : "S'usa per enviar notificacions.",
    "Send mode" : "Mode d'enviament",
    "Encryption" : "Xifrat",
    "From address" : "Des de l'adreça",
    "mail" : "correu electrònic",
    "Authentication method" : "Mètode d'autenticació",
    "Authentication required" : "Es requereix autenticació",
    "Server address" : "Adreça del servidor",
    "Port" : "Port",
    "Credentials" : "Credencials",
    "SMTP Username" : "Nom d'usuari SMTP",
    "SMTP Password" : "Contrasenya SMTP",
    "Store credentials" : "Emmagatzemar credencials",
    "Test email settings" : "Prova l'arranjament del correu",
    "Send email" : "Envia correu",
    "Server-side encryption" : "Xifrat del costat del servidor",
    "Enable server-side encryption" : "Habilitar xifrat en el servidor",
    "Enable encryption" : "Habilitar xifrat",
    "Start migration" : "Iniciar migració",
    "Security & setup warnings" : "Avisos de seguretat i configuració",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "S'ha habilitat la configuració de només lectura. Això no permet ajustar algunes configuracions a través de la interfície web. A més, l'arxiu ha de fer-se modificable manualment per a cada actualització.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Aparentment PHP està configurat per mostrar blocs en línia de documentació. Això farà que algunes aplicacions core siguin inaccessibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Això probablement està provocat per una cau/accelerador com Zend OPcache o eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "El mòdul de PHP 'fileinfo' no s'ha trobat. Us recomanem que habiliteu aquest mòdul per obtenir millors resultats amb la detecció mime-type.",
    "System locale can not be set to a one which supports UTF-8." : "No s'ha pogut establir cap localització del sistema amb suport per UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Això podria comportar problemes amb alguns caràcters en els noms dels fitxer.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Recomanem fermament que instal·leu els paquets requerits en el vostre sistema per suportar un dels següents idiomes: %s",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si la seva instal·lació no està situada en l'arrel del domini i usa el sistema cron, pot haver-hi problemes en generar-se els URL. Per evitar-los, configuri l'opció \"overwrite.cli.url\" en el seu arxiu config.php perquè usi la ruta de l'arrel del lloc web de la seva instal·lació (suggeriment: \"%s\")",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "No va ser possible executar cronjob via CLI. Han aparegut els següents errors tècnics:",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Última execució de la tasca cron: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Última execució de la tasca cron: %s. Alguna cosa sembla malament.",
    "Cron was not executed yet!" : "El cron encara no s'ha executat!",
    "Execute one task with each page loaded" : "Executa una tasca per cada paquet carregat",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php està registrat en un servei webcron que fa una crida a cron.php cada 15 minuts a través de http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Fer servir el cron del sistema per cridar el cron.php cada 15 minuts.",
    "Version" : "Versió",
    "Sharing" : "Compartir",
    "Allow apps to use the Share API" : "Permet que les aplicacions utilitzin l'API de compartir",
    "Allow users to share via link" : "Permet als usuaris compartir a través d'enllaços",
    "Allow public uploads" : "Permet pujada pública",
    "Enforce password protection" : "Reforça la protecció amb contrasenya",
    "Set default expiration date" : "Estableix la data de venciment",
    "Expire after " : "Venciment després de",
    "days" : "dies",
    "Enforce expiration date" : "Força la data de venciment",
    "Allow resharing" : "Permet compartir de nou",
    "Restrict users to only share with users in their groups" : "Permet als usuaris compartir només amb usuaris del seu grup",
    "Exclude groups from sharing" : "Exclou grups de compartició",
    "These groups will still be able to receive shares, but not to initiate them." : "Aquests fitxers encara podran rebre compartits, però no podran iniciar-los.",
    "Tips & tricks" : "Consells i trucs",
    "How to do backups" : "Com fer còpies de seguretat",
    "Advanced monitoring" : "Supervisió avançada",
    "Performance tuning" : "Ajust del rendiment",
    "Improving the config.php" : "Millorant el config.php",
    "Theming" : "Tematització",
    "Hardening and security guidance" : "Guia de protecció i seguretat",
    "Developer documentation" : "Documentació para desenvolupadors",
    "Documentation:" : "Documentació:",
    "User documentation" : "Documentació d'usuari",
    "Show description …" : "Mostrar descripció...",
    "Hide description …" : "Amagar descripció...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aquesta aplicació no es pot instal·lar perquè les següents dependències no es compleixen:",
    "Enable only for specific groups" : "Activa només per grups específics",
    "Common Name" : "Nom comú",
    "Valid until" : "Valid fins",
    "Issued By" : "Emès Per",
    "Valid until %s" : "Vàlid fins %s",
    "Import root certificate" : "Importa certificat root",
    "Cheers!" : "Salut!",
    "Administrator documentation" : "Documentació d'administrador",
    "Online documentation" : "Documentació en línia",
    "Forum" : "Fòrum",
    "Commercial support" : "Suport comercial",
    "Profile picture" : "Foto de perfil",
    "Upload new" : "Puja'n una de nova",
    "Remove image" : "Elimina imatge",
    "Cancel" : "Cancel·la",
    "Full name" : "Nom complet",
    "No display name set" : "No s'ha establert cap nom para mostrar",
    "Email" : "Correu electrònic",
    "Your email address" : "Correu electrònic",
    "No email address set" : "No s'ha establert cap adreça de correu",
    "You are member of the following groups:" : "Vostè és membre dels següents grups:",
    "Password" : "Contrasenya",
    "Current password" : "Contrasenya actual",
    "New password" : "Contrasenya nova",
    "Change password" : "Canvia la contrasenya",
    "Language" : "Idioma",
    "Help translate" : "Ajudeu-nos amb la traducció",
    "Get the apps to sync your files" : "Obtingueu les aplicacions per sincronitzar els vostres fitxers",
    "Desktop client" : "Client d'escriptori",
    "Android app" : "aplicació para Android",
    "iOS app" : "aplicació para iOS",
    "Show First Run Wizard again" : "Torna a mostrar l'assistent de primera execució",
    "Name" : "Nom",
    "Username" : "Nom d'usuari",
    "Show storage location" : "Mostra la ubicació del magatzem",
    "Show last log in" : "Mostrar l'últim accés",
    "Show user backend" : "Mostrar backend d'usuari",
    "Send email to new user" : "Enviar correu electrònic al nou usuari",
    "Show email address" : "Mostrar l'adreça de correu electrònic",
    "E-Mail" : "E-mail",
    "Create" : "Crea",
    "Admin Recovery Password" : "Recuperació de contrasenya d'administrador",
    "Enter the recovery password in order to recover the users files during password change" : "Escriviu la contrasenya de recuperació per a poder recuperar els fitxers dels usuaris en canviar la contrasenya",
    "Everyone" : "Tothom",
    "Admins" : "Administradors",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Escriviu la quota d'emmagatzemament (per ex.: \"512 MB\" o \"12 GB\")",
    "Other" : "Un altre",
    "Quota" : "Quota",
    "change full name" : "canvia el nom complet",
    "set new password" : "estableix nova contrasenya",
    "change email address" : "canvi d'adreça de correu electrònic",
    "Default" : "Per defecte",
    "log-level out of allowed range" : "Nivell d'autenticació fora del rang permès",
    "Language changed" : "S'ha canviat l'idioma",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Esteu seguir que voleu afegir \"{domain}\" com a un domini de confiança?",
    "Please wait...." : "Espereu...",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Tot (problemes fatals, errors, avisos, informació, depuració)",
    "Info, warnings, errors and fatal issues" : "Informació, avisos, errors i problemes fatals",
    "Warnings, errors and fatal issues" : "Avisos, errors i problemes fatals",
    "Errors and fatal issues" : "Errors i problemes fatals",
    "Fatal issues only" : "Només problemes fatals",
    "Log" : "Registre",
    "Download logfile" : "Descarregar arxiu de registre",
    "More" : "Més",
    "Less" : "Menys",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "L'arxiu de registre és més gran de 100 MB. La descàrrega pot trigar!",
    "Allow users to send mail notification for shared files" : "Permet als usuaris enviar notificacions de fitxers compartits per correu ",
    "Allow users to send mail notification for shared files to other users" : "Permetre als usuaris enviar notificacions per correu electrònic dels arxius compartits a d'altres usuaris",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "S'utilitza SQLite com a base de dades. Per a instal·lacions mes grans es recomana canviar a un altre sistema de base de dades.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "L'ús de SQLite està desaconsellat especialment quan s'usa el client d'escriptori per sincronitzar els fitxers.",
    "Experimental applications ahead" : "A partir d'aquest punt hi ha aplicacions experimentals",
    "Uninstall App" : "Desinstal·la l'aplicació",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Què tal?,<br><br>aquest missatge és per fer-li saber que ara té uncompte %s.<br><br>El seu nom d'usuari: %s<br>Accedeixi en: <a href=\"%s\">%s</a><br><br>",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hola, què tal?,\n\nAquest missatge és per fer-li saber que ara té un compte %s.\n\n El seu nom d'usuari: %s\nAccedeixi en: %s\n\n",
    "Group" : "Grup"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/ca.js <==
OC.L10N.register(
    "settings",
    {
    "Enabled" : "Activat",
    "Not enabled" : "Desactivat",
    "Wrong password" : "Contrasenya incorrecta",
    "Saved" : "Desat",
    "No user supplied" : "No heu proporcionat cap usuari",
    "Unable to change password" : "No es pot canviar la contrasenya",
    "Authentication error" : "Error d'autenticació",
    "Wrong admin recovery password. Please check the password and try again." : "La contrasenya de recuperació d'administrador és incorrecta. Comproveu-la i torneu-ho a intentar.",
    "Federated Cloud Sharing" : "Compartició federada de núvol",
    "A problem occurred, please check your log files (Error: %s)" : "S'ha produït un problema, si us plau revisi els arxius de registre (Error: %s)",
    "Migration Completed" : "Migració completada",
    "Group already exists." : "El grup ja existeix.",
    "Unable to add group." : "No es pot agregar el grup.",
    "Unable to delete group." : "No es pot esborrar el grup.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Hi ha hagut un problema en enviar el correu. Revisi la seva configuració. (Error: %s)",
    "You need to set your user email before being able to send test emails." : "Heu d'establir un nom d'usuari abans de poder enviar correus de prova.",
    "Invalid request" : "Sol·licitud no vàlida",
    "Invalid mail address" : "Adreça de correu invàlida",
    "No valid group selected" : "No s'ha seleccionat un grup vàlid",
    "A user with that name already exists." : "Ja existeix un usuari amb est nom.",
    "Unable to create user." : "No es pot crear el usuari.",
    "Unable to delete user." : "No es pot eliminar l'usuari",
    "Settings saved" : "Paràmetres desats",
    "Unable to change full name" : "No s'ha pogut canviar el nom complet",
    "Unable to change email address" : "No es pot canviar l'adreça de correu",
    "Your full name has been changed." : "El vostre nom complet ha canviat.",
    "Forbidden" : "Prohibit",
    "Invalid user" : "Usuari no vàlid",
    "Unable to change mail address" : "No es pot canviar l'adreça de correu electrònic",
    "Email saved" : "S'ha desat el correu electrònic",
    "Your %s account was created" : "S'ha creat el seu compte %s",
    "Couldn't remove app." : "No s'ha pogut eliminar l'aplicació",
    "Couldn't update app." : "No s'ha pogut actualitzar l'aplicació.",
    "Add trusted domain" : "Afegir domini de confiança",
    "Migration in progress. Please wait until the migration is finished" : "Migració en progrés. Si us plau, espereu fins que finalitzi la migració",
    "Migration started …" : "Migració iniciada ...",
    "Not saved" : "No desat",
    "Email sent" : "El correu electrónic s'ha enviat",
    "Official" : "Oficial",
    "All" : "Tots",
    "Update to %s" : "Actualitzar a %s",
    "No apps found for your version" : "No s'han trobat aplicacions per la seva versió",
    "Error while disabling app" : "Error en desactivar l'aplicació",
    "Disable" : "Desactiva",
    "Enable" : "Habilita",
    "Enabling app …" : "Activant aplicació...",
    "Error while enabling app" : "Error en activar l'aplicació",
    "Updating...." : "Actualitzant...",
    "Error while updating app" : "Error en actualitzar l'aplicació",
    "Updated" : "Actualitzada",
    "Error while uninstalling app" : "Error en desinstal·lar l'aplicació",
    "Uninstall" : "Desinstal·la",
    "App update" : "Actualització de la App",
    "Approved" : "Aprovat",
    "Experimental" : "Experimental",
    "Disconnect" : "Desconnecta",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome per Android",
    "iPhone iOS" : "iPhone iOS",
    "iPad iOS" : "iPad iOS",
    "iOS Client" : "iOS Client",
    "Android Client" : "Client Android",
    "This session" : "Aquesta sessió",
    "Copy" : "Copia",
    "Copied!" : "Copiat!",
    "Not supported!" : "No soportat!",
    "Press ⌘-C to copy." : "Prem ⌘-C per copiar.",
    "Press Ctrl-C to copy." : "Prem Ctrl-C per copiar.",
    "Valid until {date}" : "Vàlid fins {date}",
    "Delete" : "Esborra",
    "Local" : "Local",
    "Private" : "Privat",
    "Only visible to local users" : "Només visible per a usuaris locals",
    "Only visible to you" : "Només visible per tu",
    "Contacts" : "Contactes",
    "Public" : "Públic",
    "Select a profile picture" : "Seleccioneu una imatge de perfil",
    "Very weak password" : "Contrasenya massa feble",
    "Weak password" : "Contrasenya feble",
    "So-so password" : "Contrasenya passable",
    "Good password" : "Contrasenya bona",
    "Strong password" : "Contrasenya forta",
    "Groups" : "Grups",
    "Unable to delete {objName}" : "No es pot eliminar {objName}",
    "A valid group name must be provided" : "Heu de facilitar un nom de grup vàlid",
    "deleted {groupName}" : "eliminat {groupName}",
    "undo" : "desfés",
    "never" : "mai",
    "deleted {userName}" : "eliminat {userName}",
    "Add group" : "Afegeix grup",
    "no group" : "sense grup",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Canviar la contrasenya provocarà pèrdua de dades, perquè la recuperació de dades no està disponible per a aquest usuari",
    "A valid username must be provided" : "Heu de facilitar un nom d'usuari vàlid",
    "A valid password must be provided" : "Heu de facilitar una contrasenya vàlida",
    "A valid email must be provided" : "S'ha de subministrar una adreça de correu electrònic vàlida",
    "__language_name__" : "Català",
    "Unlimited" : "Il·limitat",
    "Personal info" : "Informació personal",
    "Sessions" : "Sessions",
    "App passwords" : "Contrasenyes de l'Apliació",
    "Sync clients" : "Sincronitzar clients",
    "None" : "Cap",
    "Login" : "Inici de sessió",
    "Plain" : "Pla",
    "NT LAN Manager" : "Gestor NT LAN",
    "Email server" : "Servidor de correu electrònic",
    "Open documentation" : "Obre la documentació",
    "This is used for sending out notifications." : "S'usa per enviar notificacions.",
    "Send mode" : "Mode d'enviament",
    "Encryption" : "Xifrat",
    "From address" : "Des de l'adreça",
    "mail" : "correu electrònic",
    "Authentication method" : "Mètode d'autenticació",
    "Authentication required" : "Es requereix autenticació",
    "Server address" : "Adreça del servidor",
    "Port" : "Port",
    "Credentials" : "Credencials",
    "SMTP Username" : "Nom d'usuari SMTP",
    "SMTP Password" : "Contrasenya SMTP",
    "Store credentials" : "Emmagatzemar credencials",
    "Test email settings" : "Prova l'arranjament del correu",
    "Send email" : "Envia correu",
    "Server-side encryption" : "Xifrat del costat del servidor",
    "Enable server-side encryption" : "Habilitar xifrat en el servidor",
    "Enable encryption" : "Habilitar xifrat",
    "Start migration" : "Iniciar migració",
    "Security & setup warnings" : "Avisos de seguretat i configuració",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "S'ha habilitat la configuració de només lectura. Això no permet ajustar algunes configuracions a través de la interfície web. A més, l'arxiu ha de fer-se modificable manualment per a cada actualització.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Aparentment PHP està configurat per mostrar blocs en línia de documentació. Això farà que algunes aplicacions core siguin inaccessibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Això probablement està provocat per una cau/accelerador com Zend OPcache o eAccelerator.",
    "System locale can not be set to a one which supports UTF-8." : "No s'ha pogut establir cap localització del sistema amb suport per UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Això podria comportar problemes amb alguns caràcters en els noms dels fitxer.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Recomanem fermament que instal·leu els paquets requerits en el vostre sistema per suportar un dels següents idiomes: %s",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si la seva instal·lació no està situada en l'arrel del domini i usa el sistema cron, pot haver-hi problemes en generar-se els URL. Per evitar-los, configuri l'opció \"overwrite.cli.url\" en el seu arxiu config.php perquè usi la ruta de l'arrel del lloc web de la seva instal·lació (suggeriment: \"%s\")",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "No va ser possible executar cronjob via CLI. Han aparegut els següents errors tècnics:",
    "All checks passed." : "Totes les comprovacions correctes.",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Última execució de la tasca cron: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Última execució de la tasca cron: %s. Alguna cosa sembla malament.",
    "Cron was not executed yet!" : "El cron encara no s'ha executat!",
    "Execute one task with each page loaded" : "Executa una tasca per cada paquet carregat",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php està registrat en un servei webcron que fa una crida a cron.php cada 15 minuts a través de http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Fer servir el cron del sistema per cridar el cron.php cada 15 minuts.",
    "Version" : "Versió",
    "Sharing" : "Compartir",
    "Allow apps to use the Share API" : "Permet que les aplicacions utilitzin l'API de compartir",
    "Allow users to share via link" : "Permet als usuaris compartir a través d'enllaços",
    "Allow public uploads" : "Permet pujada pública",
    "Enforce password protection" : "Reforça la protecció amb contrasenya",
    "Set default expiration date" : "Estableix la data de venciment",
    "Expire after " : "Venciment després de",
    "days" : "dies",
    "Enforce expiration date" : "Força la data de venciment",
    "Allow resharing" : "Permet compartir de nou",
    "Restrict users to only share with users in their groups" : "Permet als usuaris compartir només amb usuaris del seu grup",
    "Exclude groups from sharing" : "Exclou grups de compartició",
    "These groups will still be able to receive shares, but not to initiate them." : "Aquests fitxers encara podran rebre compartits, però no podran iniciar-los.",
    "Tips & tricks" : "Consells i trucs",
    "How to do backups" : "Com fer còpies de seguretat",
    "Advanced monitoring" : "Supervisió avançada",
    "Performance tuning" : "Ajust del rendiment",
    "Improving the config.php" : "Millorant el config.php",
    "Theming" : "Tematització",
    "Hardening and security guidance" : "Guia de protecció i seguretat",
    "Developer documentation" : "Documentació para desenvolupadors",
    "by %s" : "per %s",
    "Documentation:" : "Documentació:",
    "User documentation" : "Documentació d'usuari",
    "Visit website" : "Visita el lloc web",
    "Report a bug" : "Reportar un error",
    "Show description …" : "Mostrar descripció...",
    "Hide description …" : "Amagar descripció...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aquesta aplicació no es pot instal·lar perquè les següents dependències no es compleixen:",
    "Enable only for specific groups" : "Activa només per grups específics",
    "Uninstall app" : "Desinstala la app",
    "Common Name" : "Nom comú",
    "Valid until" : "Valid fins",
    "Issued By" : "Emès Per",
    "Valid until %s" : "Vàlid fins %s",
    "Import root certificate" : "Importa certificat root",
    "Administrator documentation" : "Documentació d'administrador",
    "Online documentation" : "Documentació en línia",
    "Forum" : "Fòrum",
    "Getting help" : "Obtenint ajuda",
    "Commercial support" : "Suport comercial",
    "Profile picture" : "Foto de perfil",
    "Upload new" : "Puja'n una de nova",
    "Remove image" : "Elimina imatge",
    "png or jpg, max. 20 MB" : "png or jpg, max. 20 MB",
    "Cancel" : "Cancel·la",
    "Choose as profile picture" : "Elegeix una imatge de perfil",
    "Full name" : "Nom complet",
    "No display name set" : "No s'ha establert cap nom para mostrar",
    "Email" : "Correu electrònic",
    "Your email address" : "Correu electrònic",
    "No email address set" : "No s'ha establert cap adreça de correu",
    "Phone number" : "Número de telèfon",
    "Your phone number" : "El teu número de telèfon",
    "Address" : "Adreça",
    "Your postal address" : "La teva adreça postal",
    "Website" : "Lloc web",
    "Your website" : "El teu lloc web",
    "Twitter" : "Twitter",
    "You are member of the following groups:" : "Vostè és membre dels següents grups:",
    "Password" : "Contrasenya",
    "Current password" : "Contrasenya actual",
    "New password" : "Contrasenya nova",
    "Change password" : "Canvia la contrasenya",
    "Language" : "Idioma",
    "Help translate" : "Ajudeu-nos amb la traducció",
    "Get the apps to sync your files" : "Obtingueu les aplicacions per sincronitzar els vostres fitxers",
    "Desktop client" : "Client d'escriptori",
    "Android app" : "aplicació para Android",
    "iOS app" : "aplicació para iOS",
    "Show First Run Wizard again" : "Torna a mostrar l'assistent de primera execució",
    "Device" : "Dispositiu",
    "Last activity" : "Última activitat",
    "Name" : "Nom",
    "App name" : "Nom de l'aplicació",
    "Create new app password" : "Crea una nova contrasenya de l'aplicació",
    "Username" : "Nom d'usuari",
    "Done" : "Fet",
    "Show storage location" : "Mostra la ubicació del magatzem",
    "Show user backend" : "Mostrar backend d'usuari",
    "Show email address" : "Mostrar l'adreça de correu electrònic",
    "Send email to new user" : "Enviar correu electrònic al nou usuari",
    "E-Mail" : "E-mail",
    "Create" : "Crea",
    "Admin Recovery Password" : "Recuperació de contrasenya d'administrador",
    "Enter the recovery password in order to recover the users files during password change" : "Escriviu la contrasenya de recuperació per a poder recuperar els fitxers dels usuaris en canviar la contrasenya",
    "Group name" : "Nom del grup",
    "Everyone" : "Tothom",
    "Admins" : "Administradors",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Escriviu la quota d'emmagatzemament (per ex.: \"512 MB\" o \"12 GB\")",
    "Other" : "Un altre",
    "Quota" : "Quota",
    "Storage location" : "Ubicació de l'emmagatzemament",
    "Last login" : "Últim accés",
    "change full name" : "canvia el nom complet",
    "set new password" : "estableix nova contrasenya",
    "change email address" : "canvi d'adreça de correu electrònic",
    "Default" : "Per defecte",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Sisplau, proporcioneu una contrasenya de recuperació d'administrador, altrament totes les dades d'usuari es perdran",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "El backend no admet canvis de contrasenya, però la clau de xifrat de l'usuari ha estat actualitzada satisfactòriament.",
    "test email settings" : "prova l'arranjament del correu",
    "Admins can't remove themself from the admin group" : "Els administradors no es poden eliminar del grup admin",
    "Unable to add user to group %s" : "No es pot afegir l'usuari al grup %s",
    "Unable to remove user from group %s" : "No es pot eliminar l'usuari del grup %s",
    "Sending..." : "Enviant...",
    "Uninstalling ...." : "Desintal·lant ...",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "El mòdul de PHP 'fileinfo' no s'ha trobat. Us recomanem que habiliteu aquest mòdul per obtenir millors resultats amb la detecció mime-type.",
    "Cheers!" : "Salut!",
    "Show last log in" : "Mostrar l'últim accés"
},
"nplurals=2; plural=(n != 1);");
